==> musikloud_1.4.3.tar.gz: musikloud-1.4.3/musikloudapp/src/base/clipboardmonitor.cpp <==
#include "clipboardmonitor.h"
#include "settings.h"
#include <QApplication>
#include <QClipboard>
#include <QDebug>
#ifdef MEEGO_EDITION_HARMATTAN
#include <QTimer>
#endif

ClipboardMonitor* ClipboardMonitor::m_instance = 0;

ClipboardMonitor::ClipboardMonitor(QObject *parent) :
    QObject(parent)
  #ifdef MEEGO_EDITION_HARMATTAN
  ,m_timer(0)
  #endif
{
    if (!m_instance) {
        m_instance = this;
    }

    this->connect(QApplication::clipboard(), SIGNAL(dataChanged()), this, SLOT(onClipboardTextChanged()));
}

ClipboardMonitor* ClipboardMonitor::instance() {
    return !m_instance ? new ClipboardMonitor : m_instance;
}

void ClipboardMonitor::onClipboardTextChanged() {
#ifdef MEEGO_EDITION_HARMATTAN
    if ((m_timer) && (m_timer->isActive())) {
        // QClipboard::dataChanged() signal is emitted twice in Harmattan, so ignore the signal if the timer is still active.
        return;
    }
    else {
        if (!m_timer) {
            m_timer = new QTimer(this);
            m_timer->setInterval(3000);
            m_timer->setSingleShot(true);
        }

        m_timer->start();
    }
#endif
    if (QApplication::clipboard()->text().contains(QRegExp("http(s|)://(www.|)soundcloud.com/\\w+"))) {
        this->setClipboardUrl(QApplication::clipboard()->text());
    }
}

void ClipboardMonitor::setClipboardUrl(const QString &url) {
    qDebug() << "Clipboard url: " + url;
    m_clipboardUrl = url;
    emit clipboardUrlChanged(url);
#ifndef SYMBIAN_OS
    if (Settings::instance()->monitorClipboard()) {
        emit gotClipboardUrl(url);
    }
#endif
}

==> musikloud_1.5.3.tar.gz: musikloud-1.5.3/musikloudapp/src/base/clipboardmonitor.cpp <==
#include "clipboardmonitor.h"
#include "settings.h"
#if QT_VERSION >= 0x050000
#include <QGuiApplication>
#else
#include <QApplication>
#endif
#include <QClipboard>
#include <QDebug>
#ifdef MEEGO_EDITION_HARMATTAN
#include <QTimer>
#endif

ClipboardMonitor* ClipboardMonitor::self = 0;

ClipboardMonitor::ClipboardMonitor(QObject *parent) :
    QObject(parent)
  #ifdef MEEGO_EDITION_HARMATTAN
  ,m_timer(0)
  #endif
{
    if (!self) {
        self = this;
    }
#if QT_VERSION >= 0x050000
    this->connect(QGuiApplication::clipboard(), SIGNAL(dataChanged()), this, SLOT(onClipboardTextChanged()));
#else
    this->connect(QApplication::clipboard(), SIGNAL(dataChanged()), this, SLOT(onClipboardTextChanged()));
#endif
}

ClipboardMonitor* ClipboardMonitor::instance() {
    return !self ? new ClipboardMonitor : self;
}

void ClipboardMonitor::onClipboardTextChanged() {
#ifdef MEEGO_EDITION_HARMATTAN
    if ((m_timer) && (m_timer->isActive())) {
        // QClipboard::dataChanged() signal is emitted twice in Harmattan, so ignore the signal if the timer is still active.
        return;
    }
    else {
        if (!m_timer) {
            m_timer = new QTimer(this);
            m_timer->setInterval(3000);
            m_timer->setSingleShot(true);
        }

        m_timer->start();
    }
#endif
#if QT_VERSION >= 0x050000
    if (QGuiApplication::clipboard()->text().contains(QRegExp("http(s|)://(www.|)soundcloud.com/\\w+"))) {
        this->setClipboardUrl(QGuiApplication::clipboard()->text());
    }
#else
    if (QApplication::clipboard()->text().contains(QRegExp("http(s|)://(www.|)soundcloud.com/\\w+"))) {
        this->setClipboardUrl(QApplication::clipboard()->text());
    }
#endif
}

void ClipboardMonitor::setClipboardUrl(const QString &url) {
    qDebug() << "Clipboard url: " + url;
    m_clipboardUrl = url;
    emit clipboardUrlChanged(url);
#ifndef SYMBIAN_OS
    if (Settings::instance()->monitorClipboard()) {
        emit gotClipboardUrl(url);
    }
#endif
}
